@@ -47,7 +47,7 @@ class BigQuery:
     def get_data(self, query=None, query_config=None, max_retries=0, time_interval=5):
 
         """
-        Fetches data from from BigQuery
+        Fetches data from from BigQuery's PandasGBQ API
         :param string query: query for fetching data from table
         :param string query_cofig: config for parameterised query
         :param string max_retries: maximum retries if data is not fetched
@@ -76,6 +76,33 @@ class BigQuery:
                 # logger.info(traceback.format_exc())
                 flag = False
 
+    def fetch_data(self, query=None, query_config=None, max_retries=0, time_interval=5):
+
+        """
+        Fetches data from from BigQuery Official API
+        :param string query: query for fetching data from table
+        :param string job_cofig: config for parameterised query
+        :param string max_retries: maximum retries if data is not fetched
+        :param integer time_interval : time interval between retries
+        """
+
+        flag = True
+        while flag is True:
+            try:
+                query_job = self.bq_client.query(query, job_config=query_config)
+                results = query_job.result()
+                results =results.to_dataframe()
+                logger.debug("Data fetched successfully")
+                return results
+            except requests.exceptions.Timeout:
+                logger.debug("readtimeot - - - waiting for {} seconds".format(time_interval))
+                max_retries = max_retries - 1
+                flag = False if max_retries <= 0 else True
+                time.sleep(time_interval)
+            except Exception as err:
+                flag = False
+                raise BigQueryDataFetchError(err) from err
+
     def execute_query(self, query, query_config=None, timeout=900, max_retries=0, time_interval=5):
 
         """
