@@ -462,4 +462,35 @@ class MySQL:
         except Exception as err:
             raise MysqlGenericError(err)
         finally:
-            connection.dispose()
\ No newline at end of file
+            connection.dispose()
+
+
+
+    @staticmethod
+    def dateframe_to_mysql_db(connection_type, dataframe, table_name, mode="append"):
+        """
+        Push data into production mysql table
+        :param pd.DataFrame data: dataframe to be appended or replaced
+        :param string table_name: name of the the target table
+        :param string mode: it can be either replace or append
+        :return:
+        """
+
+        try:
+            
+            if connection_type=="ecomm_order":
+                connection = sqlalchemy.create_engine(
+                    aws.cred['ECOMM_ORDER_DB_CONNECTION_STRING'])
+          
+        except Exception as err:
+            raise MysqlConnectionError(err)
+
+        try:
+            dataframe.to_sql(name=table_name, con=connection,
+                        if_exists=mode, index=False)
+            logger.debug("data dumped successfully")
+        except Exception as err:
+            raise MysqlGenericError(err)
+        finally:
+            connection.dispose()
+
